package com.jianziqiang.serviceboard.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jianziqiang.commonutils.R;
import com.jianziqiang.serviceboard.entity.Board;
import com.jianziqiang.serviceboard.query.BoardQuery;
import com.jianziqiang.serviceboard.service.BoardService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author BaseBoard
 * @since 2022-07-28
 */
@Api(description = "留言板管理")
@RestController
@RequestMapping("/service/board")
public class BoardController {

    @Autowired
    private BoardService service;

    @GetMapping("list")
    public R list() {
        return R.ok().data("items", service.list(null));
    }

    // 通过id进行逻辑删除
    @ApiOperation(value = "根据ID删除讲师")
    @DeleteMapping("{id}")
    public R removeById(
            @ApiParam(name = "id", value = "留言ID", required = true)
            @PathVariable String id) {
        boolean res = service.removeById(id);
        return res ? R.ok() : R.error();
    }

/*
    @ApiOperation(value = "分页讲师列表")
    @GetMapping("{page}/{limit}")
    public R pageList(
            @ApiParam(name = "page", value = "当前页码", required = true)
            @PathVariable Long page,
            @ApiParam(name = "limit", value = "每页记录数", required = true)
            @PathVariable Long limit){
        Page<Board> pageParam = new Page<>(page, limit);
        service.page(pageParam, null);
        List<Board> records = pageParam.getRecords();
        long total = pageParam.getTotal();
        return R.ok().data("total", total).data("rows", records);
    }*/

    @ApiOperation(value = "分页讲师列表")
    @GetMapping("{page}/{limit}")
    public R pageQuery(
            @ApiParam(name = "page", value = "当前页码", required = true)
            @PathVariable Long page,
            @ApiParam(name = "limit", value = "每页记录数", required = true)
            @PathVariable Long limit,
            @ApiParam(name = "boardQuery", value = "查询对象", required = false)
            BoardQuery query) {
        Page<Board> pageParam = new Page<>(page, limit);
        service.pageQuery(pageParam, query);
        List<Board> records = pageParam.getRecords();
        long total = pageParam.getTotal();
        return R.ok().data("total", total).data("rows", records);
    }

    @ApiOperation(value = "新增留言")
    @PostMapping
    public R save(
            @ApiParam(name = "board", value = "留言对象", required = true)
            @RequestBody Board board) {
        service.save(board);



        return R.ok();
    }

    @ApiOperation(value = "根据ID查询留言")
    @GetMapping("{id}")
    public R getById(
            @ApiParam(name = "id", value = "留言ID", required = true)
            @PathVariable String id){
        Board item = service.getById(id);
        return R.ok().data("item", item);
    }

    @ApiOperation(value = "根据ID修改讲师")
    @PutMapping("{id}")
    public R updateById(
            @ApiParam(name = "id", value = "讲师ID", required = true)
            @PathVariable String id,
            @ApiParam(name = "teacher", value = "讲师对象", required = true)
            @RequestBody Board item){
        item.setId(id);
        service.updateById(item);
        return R.ok();
    }

}

